/* 
    BattleMOD Copyright (C) 2007 Nico de Vries a.k.a. BattleMode.

    This file is part of BattleMOD.

    BattleMOD is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see http://www.gnu.org/licenses/.
*/

class BattleMOD extends UTMutator config(BattleMOD);

var config string CfgCheckConfig;
var config float CfgGameSpeedMultiplier;            // Total gamespeed (same as Speed Freak mutator).
var config float CfgWeaponSpeedMultiplier;          // Fire rate of weapons.
var config float CfgHoverVehicleSpeedMultiplier;    // Hoverboard speed.
var config float CfgWalkingSpeedMultiplier;         // Walking speed.
var config float CfgHealthMultiplier;               // Extra starting health.
var config float CfgJumpMultiplier;                 // Extra high jumping.
var config bool CfgbMaxAmmo;                        // Weapons get max ammo.

function InitMutator(string Options, out string ErrorMessage)
{
//  LogInternal("BattleMOD: "@self$".InitMutator(...)");

  // (Re)create default INI file BattleMOD.INI in the Config directory.
  if (CfgCheckConfig!="DO NOT REMOVE THIS!") { 
    CfgCheckConfig = "DO NOT REMOVE THIS!";
    CfgbMaxAmmo = True;
  }
  // Try to make sure values are valid. E.g. when a new version of BattleMOD has been installed.
  if (CfgGameSpeedMultiplier < 0.01) CfgGameSpeedMultiplier = 1.0;
  if (CfgWeaponSpeedMultiplier < 0.01) CfgWeaponSpeedMultiplier = 1.5;
  if (CfgHoverVehicleSpeedMultiplier < 0.01) CfgHoverVehicleSpeedMultiplier = 1.5;
  if (CfgWalkingSpeedMultiplier < 0.01) CfgWalkingSpeedMultiplier = 1.5;
  if (CfgJumpMultiplier < 0.01) CfgJumpMultiplier = 1.5;
  if (CfgHealthMultiplier < 0.01) CfgHealthMultiplier = 1.5;
  SaveConfig();

  WorldInfo.Game.SetGameSpeed(CfgGameSpeedMultiplier);

  Super.InitMutator(Options, ErrorMessage);
}

function DriverEnteredVehicle(Vehicle V, Pawn P)
{
  local UTHoverVehicle HV;

//  LogInternal("BattleMOD: "@self$".DriverEnteredVehicle("$V$","$P$")");

  HV = UTHoverVehicle(V);
  if (HV != None) {
    HV.MaxSpeed = HV.default.MaxSpeed * CfgHoverVehicleSpeedMultiplier;
    HV.GroundSpeed = HV.default.GroundSpeed * CfgHoverVehicleSpeedMultiplier;
    HV.AirSpeed = HV.default.AirSpeed * CfgHoverVehicleSpeedMultiplier;
    if (UTVehicleSimHoverboard(HV.SimObj) != None) {
      UTVehicleSimHoverboard(HV.SimObj).MaxThrustForce = UTVehicleSimHoverboard(HV.SimObj).default.MaxThrustForce * CfgHoverVehicleSpeedMultiplier;
      UTVehicleSimHoverboard(HV.SimObj).MaxUphillHelpThrust = UTVehicleSimHoverboard(HV.SimObj).default.MaxUphillHelpThrust * CfgHoverVehicleSpeedMultiplier;
      UTVehicleSimHoverboard(HV.SimObj).MaxReverseForce = UTVehicleSimHoverboard(HV.SimObj).default.MaxReverseForce * CfgHoverVehicleSpeedMultiplier;
      UTVehicleSimHoverboard(HV.SimObj).MaxReverseVelocity = UTVehicleSimHoverboard(HV.SimObj).default.MaxReverseVelocity * CfgHoverVehicleSpeedMultiplier;
      UTVehicleSimHoverboard(HV.SimObj).MaxStrafeForce = UTVehicleSimHoverboard(HV.SimObj).default.MaxStrafeForce * CfgHoverVehicleSpeedMultiplier;
      UTVehicleSimHoverboard(HV.SimObj).TurnTorqueFactor = UTVehicleSimHoverboard(HV.SimObj).default.TurnTorqueFactor * CfgHoverVehicleSpeedMultiplier;
      UTVehicleSimHoverboard(HV.SimObj).MaxTurnTorque = UTVehicleSimHoverboard(HV.SimObj).default.MaxTurnTorque * CfgHoverVehicleSpeedMultiplier;
    }
//    HV.CustomTimeDilation = SV.default.CustomTimeDilation * CfgHoverVehicleSpeedMultiplier; // works for slower but not for faster

  }

  Super.DriverEnteredVehicle(V, P);
}

function DriverLeftVehicle(Vehicle V, Pawn P)
// Not needed yet, since all players have an equal boost.
{
  Super.DriverLeftVehicle(V, P);
}

function ModifyPlayer(Pawn Other)
{
  local UTPawn P;

  P = UTPawn(Other);
  if (P != None) {
    P.FireRateMultiplier = P.default.FireRateMultiplier / CfgWeaponSpeedMultiplier;
    P.GroundSpeed = P.default.GroundSpeed * CfgWalkingSpeedMultiplier;
    P.WaterSpeed = P.default.WaterSpeed * CfgWalkingSpeedMultiplier;
    P.AirSpeed = P.default.AirSpeed * CfgWalkingSpeedMultiplier;
    P.JumpZ = P.default.JumpZ * CfgJumpMultiplier;
    P.Health = P.default.Health * CfgHealthMultiplier; 
  }

  Super.ModifyPlayer(Other);
}

function bool CheckReplacement(Actor Other)
{
  local UTWeapon W;

  if (CfgbMaxAmmo) {
	W = UTWeapon(Other);
    if ((W != None) && !W.bSuperWeapon) {
      W.Loaded(true);
    }
  }

  return true;
}

defaultproperties
{
  Name="BattleMOD"
}